@@ -1,9 +1,10 @@
 //! [Church single-pair lists](https://en.wikipedia.org/wiki/Church_encoding#One_pair_as_a_list_node)
 
-use term::*;
+use term::{Term, Error, abs, app};
+use term::Term::*;
 use term::Error::*;
-use church::booleans::*;
-use church::pairs::*;
+use church::booleans::{tru, fls};
+use church::pairs::{pair, fst, snd};
 use church::numerals::zero;
 use combinators::z;
 use std::ops::Index;
@@ -355,7 +356,7 @@ pub fn map() -> Term {
 }
 
 /// Applied to a function, a starting value and a Church list it performs a
-/// [left fold](https://en.wikipedia.org/wiki/Fold_(higher-order_function)#Folds_on_Church::lists) on the
+/// [left fold](https://en.wikipedia.org/wiki/Fold_(higher-order_function)#Folds_on_lists) on the
 /// list.
 ///
 /// FOLDL := Z (λzfsl. NULL l (λx.s) (λx.z f (f s (FST l)) (SND l)) I) =
@@ -400,7 +401,7 @@ pub fn foldl() -> Term {
 }
 
 /// Applied to a function, a starting value and a Church list it performs a
-/// [right fold](https://en.wikipedia.org/wiki/Fold_(higher-order_function)#Folds_on_Church::lists) on the
+/// [right fold](https://en.wikipedia.org/wiki/Fold_(higher-order_function)#Folds_on_lists) on the
 /// list.
 ///
 /// FOLDR := λfsl. Z (λzt. NULL t (λx.s) (λx.f (FST t) (z (SND t))) I) l =
