@@ -1,6 +1,7 @@
 //! A parser for lambda expressions
 
-use term::*;
+use term::{Term, Notation, abs, app};
+use term::Term::*;
 use self::Token::*;
 use self::CToken::*;
 use self::Error::*;
@@ -69,6 +70,7 @@ fn tokenize_dbr(input: &str) -> Result<Vec<Token>, Error> {
 fn tokenize_cla(input: &str) -> Result<Vec<CToken>, Error> {
     let mut chars = input.chars().enumerate().peekable();
     let mut tokens = Vec::new();
+    let valid_chars = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ";
 
     while let Some((i, c)) = chars.next() {
         match c {
@@ -77,7 +79,7 @@ fn tokenize_cla(input: &str) -> Result<Vec<CToken>, Error> {
                 while let Some((i, c)) = chars.next() {
                     if c == '.' {
                         break
-                    } else if "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ".contains(c) {
+                    } else if valid_chars.contains(c) {
                         name.push(c)
                     } else {
                         return Err(InvalidCharacter((i + 1, c)))
@@ -90,7 +92,7 @@ fn tokenize_cla(input: &str) -> Result<Vec<CToken>, Error> {
              _  => {
                 if c.is_whitespace() {
                     ()
-                } else if "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ".contains(c) {
+                } else if valid_chars.contains(c) {
                     let mut name = c.to_string();
                     while let Some(&(_, c)) = chars.peek() {
                         if c.is_whitespace() || c == '(' || c == ')' {
@@ -117,14 +119,14 @@ fn convert_classic_tokens(tokens: &[CToken]) -> Vec<Token> {
 
 fn _convert_classic_tokens(tokens: &[CToken], stack: &mut Vec<String>, pos: &mut usize) -> Vec<Token>
 {
-    let mut output = Vec::new();
+    let mut output = Vec::with_capacity(tokens[*pos..].len());
     let mut inner_stack_count = 0;
 
-    while *pos < tokens.len() {
-        match tokens[*pos] {
+    while let Some(token) = tokens.get(*pos) {
+        match *token {
             CLambda(ref name) => {
                 output.push(Lambda);
-                stack.push(name.clone());
+                stack.push(name.to_owned());
                 inner_stack_count += 1;
             },
             CLparen => {
@@ -138,12 +140,11 @@ fn _convert_classic_tokens(tokens: &[CToken], stack: &mut Vec<String>, pos: &mut
                 return output
             },
             CName(ref name) => {
-                let number = if stack.contains(name) {
-                    stack.iter().rev().position(|t| t == name).unwrap() + 1 // safe; ensured above
+                if let Some(index) = stack.iter().rev().position(|t| t == name) {
+                    output.push(Number(index + 1))
                 } else {
-                    stack.len() + 1
-                };
-                output.push(Number(number));
+                    output.push(Number(stack.len() + 1))
+                }
             }
         }
         *pos += 1;
@@ -167,12 +168,12 @@ fn get_ast(tokens: &[Token]) -> Result<Expression, Error> {
 }
 
 fn _get_ast(tokens: &[Token], pos: &mut usize) -> Result<Expression, Error> {
-    let mut expr = Vec::new();
-
     if tokens.is_empty() { return Err(EmptyExpression) }
 
-    while *pos < tokens.len() {
-        match tokens[*pos] {
+    let mut expr = Vec::new();
+
+    while let Some(token) = tokens.get(*pos) {
+        match *token {
             Lambda => {
                 expr.push(Abstraction)
             },
@@ -206,13 +207,13 @@ fn _get_ast(tokens: &[Token], pos: &mut usize) -> Result<Expression, Error> {
 /// # Example
 /// ```
 /// use lambda_calculus::parser::*;
-/// use lambda_calculus::church::numerals::{succ, pred};
+/// use lambda_calculus::combinators::{s, y};
 ///
-/// assert_eq!(parse(&"λn. λf. λx. n (λg. λh. h (g f)) (λu. x) (λu. u)", Classic), Ok(pred()));
-/// assert_eq!(parse(&"λn.λf.λx.n(λg.λh.h(g f))(λu.x)(λu.u)", Classic), Ok(pred()));
+/// assert_eq!(parse(&"λf.(λx.f (x x)) (λx.f (x x))", Classic), Ok(y()));
+/// assert_eq!(parse(&"λf.(λx.f(x x))(λx.f(x x))", Classic),    Ok(y()));
 ///
-/// assert_eq!(parse(  &"λλλ2(321)",  DeBruijn), Ok(succ()));
-/// assert_eq!(parse(&r#"\\\2(321)"#, DeBruijn), Ok(succ()));
+/// assert_eq!(parse(  &"λλλ31(21)",     DeBruijn), Ok(s()));
+/// assert_eq!(parse(&r#"\\\3 1 (2 1)"#, DeBruijn), Ok(s()));
 /// ```
 pub fn parse(input: &str, notation: Notation) -> Result<Term, Error> {
     let tokens = if notation == DeBruijn {
@@ -224,28 +225,27 @@ pub fn parse(input: &str, notation: Notation) -> Result<Term, Error> {
 
     let exprs = try!(if let Sequence(exprs) = ast { Ok(exprs) } else { Err(InvalidExpression) });
 
-    fold_exprs(&exprs, &mut Vec::new(), &mut Vec::new())
+    fold_exprs(&exprs)
 }
 
-fn fold_exprs(exprs: &[Expression], stack: &mut Vec<Expression>, output: &mut Vec<Term>)
-    -> Result<Term, Error>
-{
-    let iter = exprs.into_iter();
+fn fold_exprs(exprs: &[Expression]) -> Result<Term, Error> {
+    let mut depth  = 0;
+    let mut output = Vec::new();
 
-    for expr in iter {
+    for expr in exprs.iter() {
         match *expr {
             Variable(i) => output.push(Var(i)),
-            Abstraction => stack.push(Abstraction),
+            Abstraction => depth += 1,
             Sequence(ref exprs) => {
-                let subexpr = try!(fold_exprs(exprs, &mut Vec::new(), &mut Vec::new()));
+                let subexpr = try!(fold_exprs(exprs));
                 output.push(subexpr)
             }
         }
     }
 
-    let mut ret = try!(fold_terms(output.drain(..).collect()));
+    let mut ret = try!(fold_terms(output));
 
-    while let Some(Abstraction) = stack.pop() {
+    for _ in 0..depth {
         ret = abs(ret);
     }
 
