@@ -20,10 +20,10 @@ pub const LAMBDA: char = 'λ';
 ///
 /// # Example
 /// ```
-/// use lambda_calculus::church::numerals::succ;
+/// use lambda_calculus::combinators::s;
 ///
-/// assert_eq!(&format!(  "{}", succ()), "λa.λb.λc.b (a b c)"); // Classic notation
-/// assert_eq!(&format!("{:?}", succ()), "λλλ2(321)");          // DeBruijn index notation
+/// assert_eq!(&format!(  "{}", s()), "λa.λb.λc.a c (b c)"); // Classic notation
+/// assert_eq!(&format!("{:?}", s()), "λλλ31(21)");          // DeBruijn index notation
 /// ```
 #[derive(Debug, PartialEq, Clone, Copy)]
 pub enum Notation {
@@ -344,7 +344,9 @@ pub fn show_precedence_cla(term: &Term, context_precedence: usize, depth: u32) -
         },
         App(ref t1, ref t2) => {
             let ret = format!("{} {}",
-                show_precedence_cla(t1, 2, depth), show_precedence_cla(t2, 3, depth));
+                show_precedence_cla(t1, 2, depth),
+                show_precedence_cla(t2, 3, depth)
+            );
             parenthesize_if(&ret, context_precedence == 3).into()
         }
     }
@@ -368,7 +370,9 @@ pub fn show_precedence_dbr(term: &Term, context_precedence: usize, depth: u32) -
         },
         App(ref t1, ref t2) => {
             let ret = format!("{}{}",
-                show_precedence_dbr(t1, 2, depth), show_precedence_dbr(t2, 3, depth));
+                show_precedence_dbr(t1, 2, depth),
+                show_precedence_dbr(t2, 3, depth)
+            );
             parenthesize_if(&ret, context_precedence == 3).into()
         }
     }
@@ -417,8 +421,8 @@ mod tests {
 
     #[test]
     fn open_term_display() {
-        assert_eq!(&format!("{}",     abs(Var(2))) ,  "λa.b");
-        assert_eq!(&format!("{}",     abs(Var(3))) ,  "λa.c");
+        assert_eq!(&format!("{}",     abs(Var(2))) , "λa.b");
+        assert_eq!(&format!("{}",     abs(Var(3))) , "λa.c");
         assert_eq!(&format!("{}", abs(abs(Var(3)))), "λa.λb.c");
         assert_eq!(&format!("{}", abs(abs(Var(4)))), "λa.λb.d");
     }
